@@ -4,14 +4,14 @@ use strict;
 use warnings;
 use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::JSON qw(decode_json to_json);
-use GraphQL::Execution;
+use GraphQL::Execution qw(execute);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 my @DEFAULT_METHODS = qw(get post);
 my $EXECUTE = sub {
   my ($schema, $query, $root_value, $per_request, $variables, $operationName, $field_resolver) = @_;
-  GraphQL::Execution->execute(
+  execute(
     $schema,
     $query,
     $root_value,
@@ -187,7 +187,7 @@ An optional root value, passed to top-level resolvers.
 
 An optional field resolver, replacing the GraphQL default.
 
-=head2 route_handler
+=head2 handler
 
 An optional route-handler, replacing the plugin's default - see example
 above for possibilities.
